@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2017 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2018 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -236,11 +236,15 @@ $Data{'country'}{'iana'}{'new'} = {
 # UN countries
 
 $Data{'country'}{'un'}{'orig'}{'name'} = {
-   "&Aring;land Islands"                     => "Aland Islands",
-   "C&ocirc;te d'Ivoire"                     => "Cote d'Ivoire",
-   "Cura&ccedil;ao"                          => "Curacao",
-   "R\xE9union"                              => "Reunion",
-   "Saint Barth&eacute;lemy"                 => "Saint Barthelemy",
+   "&#197;land Islands"                      => "Aland Islands",
+   "C&#244;te d&#39;Ivoire"                  => "Cote d'Ivoire",
+   "Cura&#231;ao"                            => "Curacao",
+   "Democratic People&#39;s Republic of Korea" =>
+     "Democratic People's Republic of Korea",
+   "Lao People&#39;s Democratic Republic"    => "Lao People's Democratic Republic",
+   "R&#233;union"                            => "Reunion",
+   "Saint Barth&#233;lemy"                   => "Saint Barthelemy",
+   "C&#244;te d’Ivoire"                  => "Cote d'Ivoire",
 };
 
 $Data{'country'}{'un'}{'new'} = {
